@@ -1,25 +1,22 @@
 #
-# $Id: Factor.pm,v 0.06 2004/01/08 07:13:59 sts Exp $
+# $Id: Factor.pm,v 0.07 2004/01/10 23:07:03 sts Exp $
 
 package Math::Factor;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use integer;
 use strict 'vars';
 use warnings;
 
-our ($format_factors, $format_match_number,
-     $format_match_matches);
-
 use Exporter;
 use base qw(Exporter);
 
 our (@EXPORT_OK, %EXPORT_TAGS, @subs_factor,
      @subs_match, @subs);
 
-@subs_factor = qw(factor each_factor show_factor);
-@subs_match = qw(match each_match show_match);
+@subs_factor = qw(factor each_factor);
+@subs_match = qw(match each_match);
 @subs = (@subs_factor, @subs_match);
 
 @EXPORT_OK = @subs;
@@ -46,10 +43,16 @@ Math::Factor - factorise integers and calculate matching multiplications.
  # data manipulation
  %factors = factor (\@numbers);
  %matches = match (\%factors);
-
- # output
- show_factor (\%factors);
- show_match (\%matches);
+ 
+ # factors iteration
+ while ($factor = each_factor(\%factors, $numbers[0])) {
+     print "$factor\n";
+ }
+ 
+ # matches iteration
+ while (@match = each_match(\%matches, $numbers[0])) {
+     print "$numbers[0] == $match[0] * $match[1]\n";
+ }
 
 =head1 DESCRIPTION
 
@@ -172,136 +175,28 @@ sub each_match {
     }
 
     if (wantarray && @{__PACKAGE__.'::each_match'}) {
-        my @match = (${__PACKAGE__.'::each_match'}[0][0], ${__PACKAGE__.'::each_match'}[0][1]);
+        my @match = (${__PACKAGE__.'::each_match'}[0][0], 
+	  ${__PACKAGE__.'::each_match'}[0][1]);
         splice (@{__PACKAGE__.'::each_match'}, 0, 1);
         return @match;
     }
     else { ${__PACKAGE__.'::each_match'} = 0; return }
 }
 
-=head2 show_factor
-
-Outputs all numbers and their according factors to STDOUT.
-
- show_factor (\%factors);
-
- 9
- -
- 1 3 9
-
-=cut
-
-sub show_factor {
-    my $data_ref = $_[0];
-    croak q~usage: show_factors (\%factors)~
-      unless ref $data_ref eq 'HASH' && %$data_ref;
-
-    print <<'EOT';
--------
-FACTORS
--------
-
-EOT
-
-    my $ul;
-    eval $format_factors;
-    croak $@ if $@;
-
-    foreach (sort {$a <=> $b} keys %$data_ref) {
-        $ul = '-' x length;
-        write;
-    }
-}
-
-=head2 show_match
-
-Outputs all numbers and their according matching multiplications to STDOUT.
-
- show_match (\%matches);
-
- 9
- -
- 1           * 9
- 3           * 3
-
-=cut
-
-sub show_match {
-    my $data_ref = $_[0];
-    croak q~usage: show_match (\%match)~
-      unless ref $data_ref eq 'HASH' && %$data_ref;
-
-    print <<'EOT';
--------
-MATCHES
--------
-
-EOT
-
-    no warnings;
-    foreach (sort {$a <=> $b} keys %$data_ref) {
-        my $ul = '-' x length;
-
-        eval $format_match_number;
-        croak $@ if $@;
-        write;
-
-        my $i;
-        eval $format_match_matches;
-        croak $@ if $@;
-
-        for ($i = 0; $$data_ref{$_}[$i]; $i++) { write }
-
-        print <<'EOT';
-
-
-EOT
-    }
-}
-
-$format_factors = '
-    format =
-@<<<<<<<<<<<<<<<<<<<<<<<<<
-$_
-@<<<<<<<<<<<<<<<<<<<<<<<<<
-$ul
-@<<<<<<<<<<<<<<<<<<<<<<<<<
-"@{$$data_ref{$_}}"
-
-
-.
-';
-
-$format_match_number = '
-    format =
-@<<<<<<<<<<<<<<<<<<<<<<<<<
-$_
-@<<<<<<<<<<<<<<<<<<<<<<<<<
-$ul
-.
-';
-
-$format_match_matches = '
-    format =
-@<<<<<<<<<<<* @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
-$$data_ref{$_}[$i][0] $$data_ref{$_}[$i][1]
-.
-';
-
 1;
 __END__
 
 =head2 EXPORT
 
-C<factor(), match(), each_factor(), each_match(), show_factor(), show_match()> upon request.
+C<factor(), match(), each_factor(), each_match()> upon request.
 
 B<TAGS>
 
 C<:all - *()>
 
-C<:factor - factor(), each_factor(), show_factor()>
+C<:factor - factor(), each_factor()>
 
-C<:match - match(), each_match(), show_match()>
+C<:match - match(), each_match()>
 
 =head1 SEE ALSO
 
